@@ -27,7 +27,7 @@ no warnings _disabled_warnings();
 use B::Hooks::AtRuntime 'after_runtime';
 use Import::Into;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 sub import {
     my ( $class, %args ) = @_;
@@ -121,7 +121,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -522,18 +522,28 @@ useful to be able to define an C<init_arg> for unit testing.)
 
 =head1 BUGS AND LIMITATIONS
 
-When using L<Test::Compile>, there are intermittent segfaults with
-L<MooseX::Extended> unless you use C<< exclude => ['immutable'] >>. We are
-still trying to figure out wy this is happening. We are not aware of any
-production code affected by this.
+You cannot (at this time) use C<multi> subs with the debugger. This is due to
+a bug in L<Syntax::Keyword::MultiSub> that should be fixed in the next release
+of that module.
+
+If you must have multisubs and the debugger, the follow patch to
+L<Syntax::Keyword::MultiSub> fixes the issue:
+
+    --- old/lib/Syntax/Keyword/MultiSub.xs  2021-12-16 10:59:30 +0000
+    +++ new/lib/Syntax/Keyword/MultiSub.xs  2022-08-12 10:23:06 +0000
+    @@ -129,6 +129,7 @@
+     redo:
+         switch(o->op_type) {
+           case OP_NEXTSTATE:
+    +      case OP_DBSTATE:
+             o = o->op_next;
+             goto redo;
 
 See also:
 
 =over 4
 
-=item * L<The github issue|https://github.com/Ovid/moosex-extreme/issues/41>
-
-=item * L<Perlmonks discussion|https://perlmonks.org/?node_id=11145964>
+=item * L<The github issue|https://github.com/Ovid/moosex-extended/issues/45>
 
 =back
 
